@@ -20,6 +20,8 @@ Module Outline:
 
 from collections import defaultdict
 from datetime import datetime
+
+import graphviz
 from graphviz import Digraph
 import pandas as pan
 
@@ -28,7 +30,7 @@ from blackblox.bb_log import get_logger
 import blackblox.io_functions as iof
 from blackblox.dataconfig import bbcfg
 import blackblox.unitprocess as unit
-from blackblox.frames import df_unit_library
+import blackblox.frames_default as fd
 
 
 logger = get_logger("Chain")
@@ -68,10 +70,13 @@ class ProductChain:
     """
 
     def __init__(self, chain_data, name="Product Chain", xls_sheet=None, outdir=None,
-                 units_df=df_unit_library):
+                 units_df=None):
         self.name = name
         self.outdir = (outdir if outdir else bbcfg.paths.path_outdir) / f'{bbcfg.timestamp_str}__chain_{self.name}'
 
+        fd.initialize()
+        units_df = units_df if units_df is not None else fd.df_unit_library
+
         logger.info(f"PROCESS CHAIN INIT - chain name: {name}, chain data: {chain_data}, xls sheet: {xls_sheet}")
         self.process_chain_df = iof.make_df(chain_data, sheet=xls_sheet, index=None)
         self.default_product = False
@@ -449,13 +454,19 @@ class ProductChain:
 
         chain_diagram.subgraph(product_flow)   
 
-        if save is True:     # outputs as png and svg
-            chain_diagram.render()
-            chain_diagram.format = 'svg' 
-            chain_diagram.render()
+        try:
+            if save is True:     # outputs as png and svg
+                chain_diagram.render()
+                chain_diagram.format = 'svg'
+                chain_diagram.render()
 
-        if view is True:    # sends to system viewer
-            chain_diagram.view()
+            if view is True:    # sends to system viewer
+                chain_diagram.view()
+        except graphviz.backend.ExecutableNotFound:
+            print(
+                f"In processchain.py: The \"dot\" executable was not found on your system: maybe it's not installed or "
+                f"the variable dataconfig.bbcfg.graphviz_path is not set correctly."
+            )
 
         logger.debug(f"diagram created for {self.name} chain")
         return product_flow
